@@ -44,12 +44,18 @@ impl W {
         self
     }
 }
-#[doc = "GPIO_STATUS_W1TC\n\nThis register you can [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [gpio_status_w1tc](index.html) module"]
+#[doc = "GPIO_STATUS_W1TC\n\nThis register you can [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [gpio_status_w1tc]
+(index.html) module"]
 pub struct GPIO_STATUS_W1TC_SPEC;
 impl crate::RegisterSpec for GPIO_STATUS_W1TC_SPEC {
     type Ux = u32;
 }
-#[doc = "`write(|w| ..)` method takes [gpio_status_w1tc::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [gpio_status_w1tc::W]
+(W) writer structure"]
 impl crate::Writable for GPIO_STATUS_W1TC_SPEC {
     type Writer = W;
 }
