@@ -148,7 +148,7 @@ impl<'a> I2S_RECE_MSB_SHIFT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
@@ -185,7 +185,7 @@ impl<'a> I2S_TRANS_MSB_SHIFT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
@@ -222,7 +222,7 @@ impl<'a> I2S_I2S_RX_START_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
@@ -259,7 +259,7 @@ impl<'a> I2S_I2S_TX_START_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
@@ -296,7 +296,7 @@ impl<'a> I2S_MSB_RIGHT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
@@ -333,7 +333,7 @@ impl<'a> I2S_RIGHT_FIRST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
@@ -370,7 +370,7 @@ impl<'a> I2S_RECE_SLAVE_MOD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
@@ -407,7 +407,7 @@ impl<'a> I2S_TRANS_SLAVE_MOD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
@@ -444,7 +444,7 @@ impl<'a> I2S_I2S_RX_FIFO_RESET_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
@@ -481,7 +481,7 @@ impl<'a> I2S_I2S_TX_FIFO_RESET_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
@@ -518,7 +518,7 @@ impl<'a> I2S_I2S_RX_RESET_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
@@ -555,7 +555,7 @@ impl<'a> I2S_I2S_TX_RESET_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
@@ -578,62 +578,62 @@ impl R {
     #[doc = "Bit 11"]
     #[inline(always)]
     pub fn i2s_rece_msb_shift(&self) -> I2S_RECE_MSB_SHIFT_R {
-        I2S_RECE_MSB_SHIFT_R::new(((self.bits >> 11) & 0x01) != 0)
+        I2S_RECE_MSB_SHIFT_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 10"]
     #[inline(always)]
     pub fn i2s_trans_msb_shift(&self) -> I2S_TRANS_MSB_SHIFT_R {
-        I2S_TRANS_MSB_SHIFT_R::new(((self.bits >> 10) & 0x01) != 0)
+        I2S_TRANS_MSB_SHIFT_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 9"]
     #[inline(always)]
     pub fn i2s_i2s_rx_start(&self) -> I2S_I2S_RX_START_R {
-        I2S_I2S_RX_START_R::new(((self.bits >> 9) & 0x01) != 0)
+        I2S_I2S_RX_START_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 8"]
     #[inline(always)]
     pub fn i2s_i2s_tx_start(&self) -> I2S_I2S_TX_START_R {
-        I2S_I2S_TX_START_R::new(((self.bits >> 8) & 0x01) != 0)
+        I2S_I2S_TX_START_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 7"]
     #[inline(always)]
     pub fn i2s_msb_right(&self) -> I2S_MSB_RIGHT_R {
-        I2S_MSB_RIGHT_R::new(((self.bits >> 7) & 0x01) != 0)
+        I2S_MSB_RIGHT_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 6"]
     #[inline(always)]
     pub fn i2s_right_first(&self) -> I2S_RIGHT_FIRST_R {
-        I2S_RIGHT_FIRST_R::new(((self.bits >> 6) & 0x01) != 0)
+        I2S_RIGHT_FIRST_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 5"]
     #[inline(always)]
     pub fn i2s_rece_slave_mod(&self) -> I2S_RECE_SLAVE_MOD_R {
-        I2S_RECE_SLAVE_MOD_R::new(((self.bits >> 5) & 0x01) != 0)
+        I2S_RECE_SLAVE_MOD_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 4"]
     #[inline(always)]
     pub fn i2s_trans_slave_mod(&self) -> I2S_TRANS_SLAVE_MOD_R {
-        I2S_TRANS_SLAVE_MOD_R::new(((self.bits >> 4) & 0x01) != 0)
+        I2S_TRANS_SLAVE_MOD_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 3"]
     #[inline(always)]
     pub fn i2s_i2s_rx_fifo_reset(&self) -> I2S_I2S_RX_FIFO_RESET_R {
-        I2S_I2S_RX_FIFO_RESET_R::new(((self.bits >> 3) & 0x01) != 0)
+        I2S_I2S_RX_FIFO_RESET_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 2"]
     #[inline(always)]
     pub fn i2s_i2s_tx_fifo_reset(&self) -> I2S_I2S_TX_FIFO_RESET_R {
-        I2S_I2S_TX_FIFO_RESET_R::new(((self.bits >> 2) & 0x01) != 0)
+        I2S_I2S_TX_FIFO_RESET_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 1"]
     #[inline(always)]
     pub fn i2s_i2s_rx_reset(&self) -> I2S_I2S_RX_RESET_R {
-        I2S_I2S_RX_RESET_R::new(((self.bits >> 1) & 0x01) != 0)
+        I2S_I2S_RX_RESET_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 0"]
     #[inline(always)]
     pub fn i2s_i2s_tx_reset(&self) -> I2S_I2S_TX_RESET_R {
-        I2S_I2S_TX_RESET_R::new((self.bits & 0x01) != 0)
+        I2S_I2S_TX_RESET_R::new((self.bits & 1) != 0)
     }
 }
 impl W {
