@@ -67,7 +67,7 @@ impl<'a> I2S_TRANS_BCK_IN_INV_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(1 << 22)) | ((value as u32 & 1) << 22);
         self.w
     }
 }
@@ -104,7 +104,7 @@ impl<'a> I2S_RECE_DSYNC_SW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(1 << 21)) | ((value as u32 & 1) << 21);
         self.w
     }
 }
@@ -141,7 +141,7 @@ impl<'a> I2S_TRANS_DSYNC_SW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(1 << 20)) | ((value as u32 & 1) << 20);
         self.w
     }
 }
@@ -168,7 +168,7 @@ impl<'a> I2S_RECE_BCK_OUT_DELAY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 18)) | ((value as u32 & 0x03) << 18);
+        self.w.bits = (self.w.bits & !(3 << 18)) | ((value as u32 & 3) << 18);
         self.w
     }
 }
@@ -195,7 +195,7 @@ impl<'a> I2S_RECE_WS_OUT_DELAY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 16)) | ((value as u32 & 0x03) << 16);
+        self.w.bits = (self.w.bits & !(3 << 16)) | ((value as u32 & 3) << 16);
         self.w
     }
 }
@@ -222,7 +222,7 @@ impl<'a> I2S_TRANS_SD_OUT_DELAY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 14)) | ((value as u32 & 0x03) << 14);
+        self.w.bits = (self.w.bits & !(3 << 14)) | ((value as u32 & 3) << 14);
         self.w
     }
 }
@@ -249,7 +249,7 @@ impl<'a> I2S_TRANS_WS_OUT_DELAY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 12)) | ((value as u32 & 0x03) << 12);
+        self.w.bits = (self.w.bits & !(3 << 12)) | ((value as u32 & 3) << 12);
         self.w
     }
 }
@@ -276,7 +276,7 @@ impl<'a> I2S_TRANS_BCK_OUT_DELAY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 10)) | ((value as u32 & 0x03) << 10);
+        self.w.bits = (self.w.bits & !(3 << 10)) | ((value as u32 & 3) << 10);
         self.w
     }
 }
@@ -303,7 +303,7 @@ impl<'a> I2S_RECE_SD_IN_DELAY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 8)) | ((value as u32 & 0x03) << 8);
+        self.w.bits = (self.w.bits & !(3 << 8)) | ((value as u32 & 3) << 8);
         self.w
     }
 }
@@ -330,7 +330,7 @@ impl<'a> I2S_RECE_WS_IN_DELAY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 6)) | ((value as u32 & 0x03) << 6);
+        self.w.bits = (self.w.bits & !(3 << 6)) | ((value as u32 & 3) << 6);
         self.w
     }
 }
@@ -357,7 +357,7 @@ impl<'a> I2S_RECE_BCK_IN_DELAY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 4)) | ((value as u32 & 0x03) << 4);
+        self.w.bits = (self.w.bits & !(3 << 4)) | ((value as u32 & 3) << 4);
         self.w
     }
 }
@@ -384,7 +384,7 @@ impl<'a> I2S_TRANS_WS_IN_DELAY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 2)) | ((value as u32 & 0x03) << 2);
+        self.w.bits = (self.w.bits & !(3 << 2)) | ((value as u32 & 3) << 2);
         self.w
     }
 }
@@ -411,7 +411,7 @@ impl<'a> I2S_TRANS_BCK_IN_DELAY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x03) | (value as u32 & 0x03);
+        self.w.bits = (self.w.bits & !3) | (value as u32 & 3);
         self.w
     }
 }
@@ -419,67 +419,67 @@ impl R {
     #[doc = "Bit 22"]
     #[inline(always)]
     pub fn i2s_trans_bck_in_inv(&self) -> I2S_TRANS_BCK_IN_INV_R {
-        I2S_TRANS_BCK_IN_INV_R::new(((self.bits >> 22) & 0x01) != 0)
+        I2S_TRANS_BCK_IN_INV_R::new(((self.bits >> 22) & 1) != 0)
     }
     #[doc = "Bit 21"]
     #[inline(always)]
     pub fn i2s_rece_dsync_sw(&self) -> I2S_RECE_DSYNC_SW_R {
-        I2S_RECE_DSYNC_SW_R::new(((self.bits >> 21) & 0x01) != 0)
+        I2S_RECE_DSYNC_SW_R::new(((self.bits >> 21) & 1) != 0)
     }
     #[doc = "Bit 20"]
     #[inline(always)]
     pub fn i2s_trans_dsync_sw(&self) -> I2S_TRANS_DSYNC_SW_R {
-        I2S_TRANS_DSYNC_SW_R::new(((self.bits >> 20) & 0x01) != 0)
+        I2S_TRANS_DSYNC_SW_R::new(((self.bits >> 20) & 1) != 0)
     }
     #[doc = "Bits 18:19"]
     #[inline(always)]
     pub fn i2s_rece_bck_out_delay(&self) -> I2S_RECE_BCK_OUT_DELAY_R {
-        I2S_RECE_BCK_OUT_DELAY_R::new(((self.bits >> 18) & 0x03) as u8)
+        I2S_RECE_BCK_OUT_DELAY_R::new(((self.bits >> 18) & 3) as u8)
     }
     #[doc = "Bits 16:17"]
     #[inline(always)]
     pub fn i2s_rece_ws_out_delay(&self) -> I2S_RECE_WS_OUT_DELAY_R {
-        I2S_RECE_WS_OUT_DELAY_R::new(((self.bits >> 16) & 0x03) as u8)
+        I2S_RECE_WS_OUT_DELAY_R::new(((self.bits >> 16) & 3) as u8)
     }
     #[doc = "Bits 14:15"]
     #[inline(always)]
     pub fn i2s_trans_sd_out_delay(&self) -> I2S_TRANS_SD_OUT_DELAY_R {
-        I2S_TRANS_SD_OUT_DELAY_R::new(((self.bits >> 14) & 0x03) as u8)
+        I2S_TRANS_SD_OUT_DELAY_R::new(((self.bits >> 14) & 3) as u8)
     }
     #[doc = "Bits 12:13"]
     #[inline(always)]
     pub fn i2s_trans_ws_out_delay(&self) -> I2S_TRANS_WS_OUT_DELAY_R {
-        I2S_TRANS_WS_OUT_DELAY_R::new(((self.bits >> 12) & 0x03) as u8)
+        I2S_TRANS_WS_OUT_DELAY_R::new(((self.bits >> 12) & 3) as u8)
     }
     #[doc = "Bits 10:11"]
     #[inline(always)]
     pub fn i2s_trans_bck_out_delay(&self) -> I2S_TRANS_BCK_OUT_DELAY_R {
-        I2S_TRANS_BCK_OUT_DELAY_R::new(((self.bits >> 10) & 0x03) as u8)
+        I2S_TRANS_BCK_OUT_DELAY_R::new(((self.bits >> 10) & 3) as u8)
     }
     #[doc = "Bits 8:9"]
     #[inline(always)]
     pub fn i2s_rece_sd_in_delay(&self) -> I2S_RECE_SD_IN_DELAY_R {
-        I2S_RECE_SD_IN_DELAY_R::new(((self.bits >> 8) & 0x03) as u8)
+        I2S_RECE_SD_IN_DELAY_R::new(((self.bits >> 8) & 3) as u8)
     }
     #[doc = "Bits 6:7"]
     #[inline(always)]
     pub fn i2s_rece_ws_in_delay(&self) -> I2S_RECE_WS_IN_DELAY_R {
-        I2S_RECE_WS_IN_DELAY_R::new(((self.bits >> 6) & 0x03) as u8)
+        I2S_RECE_WS_IN_DELAY_R::new(((self.bits >> 6) & 3) as u8)
     }
     #[doc = "Bits 4:5"]
     #[inline(always)]
     pub fn i2s_rece_bck_in_delay(&self) -> I2S_RECE_BCK_IN_DELAY_R {
-        I2S_RECE_BCK_IN_DELAY_R::new(((self.bits >> 4) & 0x03) as u8)
+        I2S_RECE_BCK_IN_DELAY_R::new(((self.bits >> 4) & 3) as u8)
     }
     #[doc = "Bits 2:3"]
     #[inline(always)]
     pub fn i2s_trans_ws_in_delay(&self) -> I2S_TRANS_WS_IN_DELAY_R {
-        I2S_TRANS_WS_IN_DELAY_R::new(((self.bits >> 2) & 0x03) as u8)
+        I2S_TRANS_WS_IN_DELAY_R::new(((self.bits >> 2) & 3) as u8)
     }
     #[doc = "Bits 0:1"]
     #[inline(always)]
     pub fn i2s_trans_bck_in_delay(&self) -> I2S_TRANS_BCK_IN_DELAY_R {
-        I2S_TRANS_BCK_IN_DELAY_R::new((self.bits & 0x03) as u8)
+        I2S_TRANS_BCK_IN_DELAY_R::new((self.bits & 3) as u8)
     }
 }
 impl W {
