@@ -13,12 +13,16 @@ impl From<crate::R<RNG_SPEC>> for R {
         R(reader)
     }
 }
-#[doc = "RNG register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [rng](index.html) module"]
+#[doc = "RNG register\n\nThis register you can [`read`]
+(crate::generic::Reg::read). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [rng]
+(index.html) module"]
 pub struct RNG_SPEC;
 impl crate::RegisterSpec for RNG_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [rng::R](R) reader structure"]
+#[doc = "`read()` method returns [rng::R]
+(R) reader structure"]
 impl crate::Readable for RNG_SPEC {
     type Reader = R;
 }
