@@ -42,16 +42,25 @@ impl W {
         self
     }
 }
-#[doc = "RTC_GPIO_CONF\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [rtc_gpio_conf](index.html) module"]
+#[doc = "RTC_GPIO_CONF\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [rtc_gpio_conf]
+(index.html) module"]
 pub struct RTC_GPIO_CONF_SPEC;
 impl crate::RegisterSpec for RTC_GPIO_CONF_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [rtc_gpio_conf::R](R) reader structure"]
+#[doc = "`read()` method returns [rtc_gpio_conf::R]
+(R) reader structure"]
 impl crate::Readable for RTC_GPIO_CONF_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [rtc_gpio_conf::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [rtc_gpio_conf::W]
+(W) writer structure"]
 impl crate::Writable for RTC_GPIO_CONF_SPEC {
     type Writer = W;
 }
