@@ -67,7 +67,7 @@ impl<'a> SLC_TX_DSCR_EMPTY_INT_RAW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(1 << 21)) | ((value as u32 & 1) << 21);
         self.w
     }
 }
@@ -104,7 +104,7 @@ impl<'a> SLC_RX_DSCR_ERR_INT_RAW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(1 << 20)) | ((value as u32 & 1) << 20);
         self.w
     }
 }
@@ -141,7 +141,7 @@ impl<'a> SLC_TX_DSCR_ERR_INT_RAW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(1 << 19)) | ((value as u32 & 1) << 19);
         self.w
     }
 }
@@ -178,7 +178,7 @@ impl<'a> SLC_TOHOST_INT_RAW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(1 << 18)) | ((value as u32 & 1) << 18);
         self.w
     }
 }
@@ -215,7 +215,7 @@ impl<'a> SLC_RX_EOF_INT_RAW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(1 << 17)) | ((value as u32 & 1) << 17);
         self.w
     }
 }
@@ -252,7 +252,7 @@ impl<'a> SLC_RX_DONE_INT_RAW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(1 << 16)) | ((value as u32 & 1) << 16);
         self.w
     }
 }
@@ -289,7 +289,7 @@ impl<'a> SLC_TX_EOF_INT_RAW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
@@ -326,7 +326,7 @@ impl<'a> SLC_TX_DONE_INT_RAW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
@@ -363,7 +363,7 @@ impl<'a> SLC_TOKEN1_1TO0_INT_RAW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
@@ -400,7 +400,7 @@ impl<'a> SLC_TOKEN0_1TO0_INT_RAW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
@@ -437,7 +437,7 @@ impl<'a> SLC_TX_OVF_INT_RAW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
@@ -474,7 +474,7 @@ impl<'a> SLC_RX_UDF_INT_RAW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
@@ -511,7 +511,7 @@ impl<'a> SLC_TX_START_INT_RAW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
@@ -548,7 +548,7 @@ impl<'a> SLC_RX_START_INT_RAW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
@@ -585,7 +585,7 @@ impl<'a> SLC_FRHOST_BIT7_INT_RAW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
@@ -622,7 +622,7 @@ impl<'a> SLC_FRHOST_BIT6_INT_RAW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
@@ -659,7 +659,7 @@ impl<'a> SLC_FRHOST_BIT5_INT_RAW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
@@ -696,7 +696,7 @@ impl<'a> SLC_FRHOST_BIT4_INT_RAW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
@@ -733,7 +733,7 @@ impl<'a> SLC_FRHOST_BIT3_INT_RAW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
@@ -770,7 +770,7 @@ impl<'a> SLC_FRHOST_BIT2_INT_RAW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
@@ -807,7 +807,7 @@ impl<'a> SLC_FRHOST_BIT1_INT_RAW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
@@ -844,7 +844,7 @@ impl<'a> SLC_FRHOST_BIT0_INT_RAW_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
@@ -852,112 +852,112 @@ impl R {
     #[doc = "Bit 21"]
     #[inline(always)]
     pub fn slc_tx_dscr_empty_int_raw(&self) -> SLC_TX_DSCR_EMPTY_INT_RAW_R {
-        SLC_TX_DSCR_EMPTY_INT_RAW_R::new(((self.bits >> 21) & 0x01) != 0)
+        SLC_TX_DSCR_EMPTY_INT_RAW_R::new(((self.bits >> 21) & 1) != 0)
     }
     #[doc = "Bit 20"]
     #[inline(always)]
     pub fn slc_rx_dscr_err_int_raw(&self) -> SLC_RX_DSCR_ERR_INT_RAW_R {
-        SLC_RX_DSCR_ERR_INT_RAW_R::new(((self.bits >> 20) & 0x01) != 0)
+        SLC_RX_DSCR_ERR_INT_RAW_R::new(((self.bits >> 20) & 1) != 0)
     }
     #[doc = "Bit 19"]
     #[inline(always)]
     pub fn slc_tx_dscr_err_int_raw(&self) -> SLC_TX_DSCR_ERR_INT_RAW_R {
-        SLC_TX_DSCR_ERR_INT_RAW_R::new(((self.bits >> 19) & 0x01) != 0)
+        SLC_TX_DSCR_ERR_INT_RAW_R::new(((self.bits >> 19) & 1) != 0)
     }
     #[doc = "Bit 18"]
     #[inline(always)]
     pub fn slc_tohost_int_raw(&self) -> SLC_TOHOST_INT_RAW_R {
-        SLC_TOHOST_INT_RAW_R::new(((self.bits >> 18) & 0x01) != 0)
+        SLC_TOHOST_INT_RAW_R::new(((self.bits >> 18) & 1) != 0)
     }
     #[doc = "Bit 17"]
     #[inline(always)]
     pub fn slc_rx_eof_int_raw(&self) -> SLC_RX_EOF_INT_RAW_R {
-        SLC_RX_EOF_INT_RAW_R::new(((self.bits >> 17) & 0x01) != 0)
+        SLC_RX_EOF_INT_RAW_R::new(((self.bits >> 17) & 1) != 0)
     }
     #[doc = "Bit 16"]
     #[inline(always)]
     pub fn slc_rx_done_int_raw(&self) -> SLC_RX_DONE_INT_RAW_R {
-        SLC_RX_DONE_INT_RAW_R::new(((self.bits >> 16) & 0x01) != 0)
+        SLC_RX_DONE_INT_RAW_R::new(((self.bits >> 16) & 1) != 0)
     }
     #[doc = "Bit 15"]
     #[inline(always)]
     pub fn slc_tx_eof_int_raw(&self) -> SLC_TX_EOF_INT_RAW_R {
-        SLC_TX_EOF_INT_RAW_R::new(((self.bits >> 15) & 0x01) != 0)
+        SLC_TX_EOF_INT_RAW_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bit 14"]
     #[inline(always)]
     pub fn slc_tx_done_int_raw(&self) -> SLC_TX_DONE_INT_RAW_R {
-        SLC_TX_DONE_INT_RAW_R::new(((self.bits >> 14) & 0x01) != 0)
+        SLC_TX_DONE_INT_RAW_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 13"]
     #[inline(always)]
     pub fn slc_token1_1to0_int_raw(&self) -> SLC_TOKEN1_1TO0_INT_RAW_R {
-        SLC_TOKEN1_1TO0_INT_RAW_R::new(((self.bits >> 13) & 0x01) != 0)
+        SLC_TOKEN1_1TO0_INT_RAW_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 12"]
     #[inline(always)]
     pub fn slc_token0_1to0_int_raw(&self) -> SLC_TOKEN0_1TO0_INT_RAW_R {
-        SLC_TOKEN0_1TO0_INT_RAW_R::new(((self.bits >> 12) & 0x01) != 0)
+        SLC_TOKEN0_1TO0_INT_RAW_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 11"]
     #[inline(always)]
     pub fn slc_tx_ovf_int_raw(&self) -> SLC_TX_OVF_INT_RAW_R {
-        SLC_TX_OVF_INT_RAW_R::new(((self.bits >> 11) & 0x01) != 0)
+        SLC_TX_OVF_INT_RAW_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 10"]
     #[inline(always)]
     pub fn slc_rx_udf_int_raw(&self) -> SLC_RX_UDF_INT_RAW_R {
-        SLC_RX_UDF_INT_RAW_R::new(((self.bits >> 10) & 0x01) != 0)
+        SLC_RX_UDF_INT_RAW_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 9"]
     #[inline(always)]
     pub fn slc_tx_start_int_raw(&self) -> SLC_TX_START_INT_RAW_R {
-        SLC_TX_START_INT_RAW_R::new(((self.bits >> 9) & 0x01) != 0)
+        SLC_TX_START_INT_RAW_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 8"]
     #[inline(always)]
     pub fn slc_rx_start_int_raw(&self) -> SLC_RX_START_INT_RAW_R {
-        SLC_RX_START_INT_RAW_R::new(((self.bits >> 8) & 0x01) != 0)
+        SLC_RX_START_INT_RAW_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 7"]
     #[inline(always)]
     pub fn slc_frhost_bit7_int_raw(&self) -> SLC_FRHOST_BIT7_INT_RAW_R {
-        SLC_FRHOST_BIT7_INT_RAW_R::new(((self.bits >> 7) & 0x01) != 0)
+        SLC_FRHOST_BIT7_INT_RAW_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 6"]
     #[inline(always)]
     pub fn slc_frhost_bit6_int_raw(&self) -> SLC_FRHOST_BIT6_INT_RAW_R {
-        SLC_FRHOST_BIT6_INT_RAW_R::new(((self.bits >> 6) & 0x01) != 0)
+        SLC_FRHOST_BIT6_INT_RAW_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 5"]
     #[inline(always)]
     pub fn slc_frhost_bit5_int_raw(&self) -> SLC_FRHOST_BIT5_INT_RAW_R {
-        SLC_FRHOST_BIT5_INT_RAW_R::new(((self.bits >> 5) & 0x01) != 0)
+        SLC_FRHOST_BIT5_INT_RAW_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 4"]
     #[inline(always)]
     pub fn slc_frhost_bit4_int_raw(&self) -> SLC_FRHOST_BIT4_INT_RAW_R {
-        SLC_FRHOST_BIT4_INT_RAW_R::new(((self.bits >> 4) & 0x01) != 0)
+        SLC_FRHOST_BIT4_INT_RAW_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 3"]
     #[inline(always)]
     pub fn slc_frhost_bit3_int_raw(&self) -> SLC_FRHOST_BIT3_INT_RAW_R {
-        SLC_FRHOST_BIT3_INT_RAW_R::new(((self.bits >> 3) & 0x01) != 0)
+        SLC_FRHOST_BIT3_INT_RAW_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 2"]
     #[inline(always)]
     pub fn slc_frhost_bit2_int_raw(&self) -> SLC_FRHOST_BIT2_INT_RAW_R {
-        SLC_FRHOST_BIT2_INT_RAW_R::new(((self.bits >> 2) & 0x01) != 0)
+        SLC_FRHOST_BIT2_INT_RAW_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 1"]
     #[inline(always)]
     pub fn slc_frhost_bit1_int_raw(&self) -> SLC_FRHOST_BIT1_INT_RAW_R {
-        SLC_FRHOST_BIT1_INT_RAW_R::new(((self.bits >> 1) & 0x01) != 0)
+        SLC_FRHOST_BIT1_INT_RAW_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 0"]
     #[inline(always)]
     pub fn slc_frhost_bit0_int_raw(&self) -> SLC_FRHOST_BIT0_INT_RAW_R {
-        SLC_FRHOST_BIT0_INT_RAW_R::new((self.bits & 0x01) != 0)
+        SLC_FRHOST_BIT0_INT_RAW_R::new((self.bits & 1) != 0)
     }
 }
 impl W {
