@@ -81,16 +81,25 @@ impl W {
         self
     }
 }
-#[doc = "SLC_INTVEC_TOHOST\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [slc_intvec_tohost](index.html) module"]
+#[doc = "SLC_INTVEC_TOHOST\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [slc_intvec_tohost]
+(index.html) module"]
 pub struct SLC_INTVEC_TOHOST_SPEC;
 impl crate::RegisterSpec for SLC_INTVEC_TOHOST_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [slc_intvec_tohost::R](R) reader structure"]
+#[doc = "`read()` method returns [slc_intvec_tohost::R]
+(R) reader structure"]
 impl crate::Readable for SLC_INTVEC_TOHOST_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [slc_intvec_tohost::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [slc_intvec_tohost::W]
+(W) writer structure"]
 impl crate::Writable for SLC_INTVEC_TOHOST_SPEC {
     type Writer = W;
 }
