@@ -67,7 +67,7 @@ impl<'a> SPI_WR_BIT_ORDER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 26)) | ((value as u32 & 0x01) << 26);
+        self.w.bits = (self.w.bits & !(1 << 26)) | ((value as u32 & 1) << 26);
         self.w
     }
 }
@@ -104,7 +104,7 @@ impl<'a> SPI_RD_BIT_ORDER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
+        self.w.bits = (self.w.bits & !(1 << 25)) | ((value as u32 & 1) << 25);
         self.w
     }
 }
@@ -141,7 +141,7 @@ impl<'a> SPI_QIO_MODE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(1 << 24)) | ((value as u32 & 1) << 24);
         self.w
     }
 }
@@ -178,7 +178,7 @@ impl<'a> SPI_DIO_MODE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
+        self.w.bits = (self.w.bits & !(1 << 23)) | ((value as u32 & 1) << 23);
         self.w
     }
 }
@@ -215,7 +215,7 @@ impl<'a> SPI_QOUT_MODE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(1 << 20)) | ((value as u32 & 1) << 20);
         self.w
     }
 }
@@ -252,7 +252,7 @@ impl<'a> SPI_DOUT_MODE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
@@ -289,7 +289,7 @@ impl<'a> SPI_FASTRD_MODE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
@@ -326,7 +326,7 @@ impl<'a> TWO_BYTE_STATUS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(1 << 22)) | ((value as u32 & 1) << 22);
         self.w
     }
 }
@@ -363,7 +363,7 @@ impl<'a> WP_REG_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(1 << 21)) | ((value as u32 & 1) << 21);
         self.w
     }
 }
@@ -400,7 +400,7 @@ impl<'a> SHARE_BUT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(1 << 19)) | ((value as u32 & 1) << 19);
         self.w
     }
 }
@@ -437,7 +437,7 @@ impl<'a> HOLD_MODE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(1 << 18)) | ((value as u32 & 1) << 18);
         self.w
     }
 }
@@ -474,7 +474,7 @@ impl<'a> ENABLE_AHB_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(1 << 17)) | ((value as u32 & 1) << 17);
         self.w
     }
 }
@@ -511,7 +511,7 @@ impl<'a> SST_AAI_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(1 << 16)) | ((value as u32 & 1) << 16);
         self.w
     }
 }
@@ -548,7 +548,7 @@ impl<'a> RES_AND_RES_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
@@ -556,72 +556,72 @@ impl R {
     #[doc = "Bit 26 - In \"command\", \"address\", \"write-data\" (MOSI) phases, 1: LSB first; 0: MSB first"]
     #[inline(always)]
     pub fn spi_wr_bit_order(&self) -> SPI_WR_BIT_ORDER_R {
-        SPI_WR_BIT_ORDER_R::new(((self.bits >> 26) & 0x01) != 0)
+        SPI_WR_BIT_ORDER_R::new(((self.bits >> 26) & 1) != 0)
     }
     #[doc = "Bit 25 - In \"read-data\" (MISO) phase, 1: LSB first; 0: MSB first"]
     #[inline(always)]
     pub fn spi_rd_bit_order(&self) -> SPI_RD_BIT_ORDER_R {
-        SPI_RD_BIT_ORDER_R::new(((self.bits >> 25) & 0x01) != 0)
+        SPI_RD_BIT_ORDER_R::new(((self.bits >> 25) & 1) != 0)
     }
     #[doc = "Bit 24 - In the read operations, \"address\" phase and \"read-data\" phase apply 4 signals"]
     #[inline(always)]
     pub fn spi_qio_mode(&self) -> SPI_QIO_MODE_R {
-        SPI_QIO_MODE_R::new(((self.bits >> 24) & 0x01) != 0)
+        SPI_QIO_MODE_R::new(((self.bits >> 24) & 1) != 0)
     }
     #[doc = "Bit 23 - In the read operations, \"address\" phase and \"read-data\" phase apply 2 signals"]
     #[inline(always)]
     pub fn spi_dio_mode(&self) -> SPI_DIO_MODE_R {
-        SPI_DIO_MODE_R::new(((self.bits >> 23) & 0x01) != 0)
+        SPI_DIO_MODE_R::new(((self.bits >> 23) & 1) != 0)
     }
     #[doc = "Bit 20 - In the read operations, \"read-data\" phase apply 4 signals"]
     #[inline(always)]
     pub fn spi_qout_mode(&self) -> SPI_QOUT_MODE_R {
-        SPI_QOUT_MODE_R::new(((self.bits >> 20) & 0x01) != 0)
+        SPI_QOUT_MODE_R::new(((self.bits >> 20) & 1) != 0)
     }
     #[doc = "Bit 14 - In the read operations, \"read-data\" phase apply 2 signals"]
     #[inline(always)]
     pub fn spi_dout_mode(&self) -> SPI_DOUT_MODE_R {
-        SPI_DOUT_MODE_R::new(((self.bits >> 14) & 0x01) != 0)
+        SPI_DOUT_MODE_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 13 - this bit enable the bits: spi_qio_mode, spi_dio_mode, spi_qout_mode and spi_dout_mode"]
     #[inline(always)]
     pub fn spi_fastrd_mode(&self) -> SPI_FASTRD_MODE_R {
-        SPI_FASTRD_MODE_R::new(((self.bits >> 13) & 0x01) != 0)
+        SPI_FASTRD_MODE_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 22 - Enable two byte status"]
     #[inline(always)]
     pub fn two_byte_status(&self) -> TWO_BYTE_STATUS_R {
-        TWO_BYTE_STATUS_R::new(((self.bits >> 22) & 0x01) != 0)
+        TWO_BYTE_STATUS_R::new(((self.bits >> 22) & 1) != 0)
     }
     #[doc = "Bit 21 - Write protect?"]
     #[inline(always)]
     pub fn wp_reg(&self) -> WP_REG_R {
-        WP_REG_R::new(((self.bits >> 21) & 0x01) != 0)
+        WP_REG_R::new(((self.bits >> 21) & 1) != 0)
     }
     #[doc = "Bit 19 - Share bus"]
     #[inline(always)]
     pub fn share_but(&self) -> SHARE_BUT_R {
-        SHARE_BUT_R::new(((self.bits >> 19) & 0x01) != 0)
+        SHARE_BUT_R::new(((self.bits >> 19) & 1) != 0)
     }
     #[doc = "Bit 18 - Hold mode"]
     #[inline(always)]
     pub fn hold_mode(&self) -> HOLD_MODE_R {
-        HOLD_MODE_R::new(((self.bits >> 18) & 0x01) != 0)
+        HOLD_MODE_R::new(((self.bits >> 18) & 1) != 0)
     }
     #[doc = "Bit 17 - Enable AHB"]
     #[inline(always)]
     pub fn enable_ahb(&self) -> ENABLE_AHB_R {
-        ENABLE_AHB_R::new(((self.bits >> 17) & 0x01) != 0)
+        ENABLE_AHB_R::new(((self.bits >> 17) & 1) != 0)
     }
     #[doc = "Bit 16 - SST_AAI?"]
     #[inline(always)]
     pub fn sst_aai(&self) -> SST_AAI_R {
-        SST_AAI_R::new(((self.bits >> 16) & 0x01) != 0)
+        SST_AAI_R::new(((self.bits >> 16) & 1) != 0)
     }
     #[doc = "Bit 15 - 'Res and res'?"]
     #[inline(always)]
     pub fn res_and_res(&self) -> RES_AND_RES_R {
-        RES_AND_RES_R::new(((self.bits >> 15) & 0x01) != 0)
+        RES_AND_RES_R::new(((self.bits >> 15) & 1) != 0)
     }
 }
 impl W {
