@@ -67,7 +67,7 @@ impl<'a> ERASE_ENABLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
         self.w
     }
 }
@@ -129,7 +129,7 @@ impl R {
     #[doc = "Bit 31"]
     #[inline(always)]
     pub fn erase_enable(&self) -> ERASE_ENABLE_R {
-        ERASE_ENABLE_R::new(((self.bits >> 31) & 0x01) != 0)
+        ERASE_ENABLE_R::new(((self.bits >> 31) & 1) != 0)
     }
     #[doc = "Bits 16:19"]
     #[inline(always)]
@@ -165,16 +165,25 @@ impl W {
         self
     }
 }
-#[doc = "\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_ext1](index.html) module"]
+#[doc = "\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_ext1]
+(index.html) module"]
 pub struct SPI_EXT1_SPEC;
 impl crate::RegisterSpec for SPI_EXT1_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [spi_ext1::R](R) reader structure"]
+#[doc = "`read()` method returns [spi_ext1::R]
+(R) reader structure"]
 impl crate::Readable for SPI_EXT1_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [spi_ext1::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [spi_ext1::W]
+(W) writer structure"]
 impl crate::Writable for SPI_EXT1_SPEC {
     type Writer = W;
 }
