@@ -57,7 +57,7 @@ impl<'a> REG_INT_HOLD_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x03) | (value as u32 & 0x03);
+        self.w.bits = (self.w.bits & !3) | (value as u32 & 3);
         self.w
     }
 }
@@ -65,7 +65,7 @@ impl R {
     #[doc = "Bits 0:1 - This register is for two SPI masters to share the same cs, clock and data signals."]
     #[inline(always)]
     pub fn reg_int_hold_ena(&self) -> REG_INT_HOLD_ENA_R {
-        REG_INT_HOLD_ENA_R::new((self.bits & 0x03) as u8)
+        REG_INT_HOLD_ENA_R::new((self.bits & 3) as u8)
     }
 }
 impl W {
@@ -81,16 +81,25 @@ impl W {
         self
     }
 }
-#[doc = "This register is for two SPI masters to share the same cs, clock and data signals.\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_ext3](index.html) module"]
+#[doc = "This register is for two SPI masters to share the same cs, clock and data signals.\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_ext3]
+(index.html) module"]
 pub struct SPI_EXT3_SPEC;
 impl crate::RegisterSpec for SPI_EXT3_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [spi_ext3::R](R) reader structure"]
+#[doc = "`read()` method returns [spi_ext3::R]
+(R) reader structure"]
 impl crate::Readable for SPI_EXT3_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [spi_ext3::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [spi_ext3::W]
+(W) writer structure"]
 impl crate::Writable for SPI_EXT3_SPEC {
     type Writer = W;
 }
