@@ -67,7 +67,7 @@ impl<'a> SPI_SYNC_RESET_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
         self.w
     }
 }
@@ -104,7 +104,7 @@ impl<'a> SPI_SLAVE_MODE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
+        self.w.bits = (self.w.bits & !(1 << 30)) | ((value as u32 & 1) << 30);
         self.w
     }
 }
@@ -141,7 +141,7 @@ impl<'a> SLV_CMD_DEFINE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(1 << 27)) | ((value as u32 & 1) << 27);
         self.w
     }
 }
@@ -220,7 +220,7 @@ impl<'a> SPI_TRANS_DONE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
@@ -257,7 +257,7 @@ impl<'a> SLV_WR_STA_DONE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
@@ -294,7 +294,7 @@ impl<'a> SLV_RD_STA_DONE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
@@ -331,7 +331,7 @@ impl<'a> SLV_WR_BUF_DONE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
@@ -368,7 +368,7 @@ impl<'a> SLV_RD_BUF_DONE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
@@ -405,7 +405,7 @@ impl<'a> SPI_BUFFER_ENABLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
+        self.w.bits = (self.w.bits & !(1 << 29)) | ((value as u32 & 1) << 29);
         self.w
     }
 }
@@ -442,7 +442,7 @@ impl<'a> STA_ENABLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 28)) | ((value as u32 & 0x01) << 28);
+        self.w.bits = (self.w.bits & !(1 << 28)) | ((value as u32 & 1) << 28);
         self.w
     }
 }
@@ -479,7 +479,7 @@ impl<'a> INTERRUPT_TRANS_ENABLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
@@ -516,7 +516,7 @@ impl<'a> INTERRUPT_WS_ENABLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
@@ -553,7 +553,7 @@ impl<'a> INTERRUPT_RS_ENABLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
@@ -590,7 +590,7 @@ impl<'a> INTERRUPT_WB_ENABLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
@@ -627,7 +627,7 @@ impl<'a> INTERRUPT_RB_ENABLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
@@ -635,17 +635,17 @@ impl R {
     #[doc = "Bit 31 - It is the synchronous reset signal of the module. This bit is self-cleared by hardware."]
     #[inline(always)]
     pub fn spi_sync_reset(&self) -> SPI_SYNC_RESET_R {
-        SPI_SYNC_RESET_R::new(((self.bits >> 31) & 0x01) != 0)
+        SPI_SYNC_RESET_R::new(((self.bits >> 31) & 1) != 0)
     }
     #[doc = "Bit 30 - 1: slave mode, 0: master mode."]
     #[inline(always)]
     pub fn spi_slave_mode(&self) -> SPI_SLAVE_MODE_R {
-        SPI_SLAVE_MODE_R::new(((self.bits >> 30) & 0x01) != 0)
+        SPI_SLAVE_MODE_R::new(((self.bits >> 30) & 1) != 0)
     }
     #[doc = "Bit 27 - 1: slave mode commands are defined in SPI_SLAVE3. 0: slave mode commands are fixed as 1: \"write-status\"; 4: \"read-status\"; 2: \"write-buffer\" and 3: \"read-buffer\"."]
     #[inline(always)]
     pub fn slv_cmd_define(&self) -> SLV_CMD_DEFINE_R {
-        SLV_CMD_DEFINE_R::new(((self.bits >> 27) & 0x01) != 0)
+        SLV_CMD_DEFINE_R::new(((self.bits >> 27) & 1) != 0)
     }
     #[doc = "Bits 23:26 - The operations counter in both the master mode and the slave mode."]
     #[inline(always)]
@@ -660,62 +660,62 @@ impl R {
     #[doc = "Bit 4 - The interrupt raw bit for the completement of any operation in both the master mode and the slave mode."]
     #[inline(always)]
     pub fn spi_trans_done(&self) -> SPI_TRANS_DONE_R {
-        SPI_TRANS_DONE_R::new(((self.bits >> 4) & 0x01) != 0)
+        SPI_TRANS_DONE_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 3 - The interrupt raw bit for the completement of \"write-status\" operation in the slave mode."]
     #[inline(always)]
     pub fn slv_wr_sta_done(&self) -> SLV_WR_STA_DONE_R {
-        SLV_WR_STA_DONE_R::new(((self.bits >> 3) & 0x01) != 0)
+        SLV_WR_STA_DONE_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 2 - The interrupt raw bit for the completement of \"read-status\" operation in the slave mode."]
     #[inline(always)]
     pub fn slv_rd_sta_done(&self) -> SLV_RD_STA_DONE_R {
-        SLV_RD_STA_DONE_R::new(((self.bits >> 2) & 0x01) != 0)
+        SLV_RD_STA_DONE_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 1 - The interrupt raw bit for the completement of \"write-buffer\" operation in the slave mode."]
     #[inline(always)]
     pub fn slv_wr_buf_done(&self) -> SLV_WR_BUF_DONE_R {
-        SLV_WR_BUF_DONE_R::new(((self.bits >> 1) & 0x01) != 0)
+        SLV_WR_BUF_DONE_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 0 - The interrupt raw bit for the completement of \"read-buffer\" operation in the slave mode."]
     #[inline(always)]
     pub fn slv_rd_buf_done(&self) -> SLV_RD_BUF_DONE_R {
-        SLV_RD_BUF_DONE_R::new((self.bits & 0x01) != 0)
+        SLV_RD_BUF_DONE_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 29 - Enable read/write buffer"]
     #[inline(always)]
     pub fn spi_buffer_enable(&self) -> SPI_BUFFER_ENABLE_R {
-        SPI_BUFFER_ENABLE_R::new(((self.bits >> 29) & 0x01) != 0)
+        SPI_BUFFER_ENABLE_R::new(((self.bits >> 29) & 1) != 0)
     }
     #[doc = "Bit 28 - Enable read/write buffer"]
     #[inline(always)]
     pub fn sta_enable(&self) -> STA_ENABLE_R {
-        STA_ENABLE_R::new(((self.bits >> 28) & 0x01) != 0)
+        STA_ENABLE_R::new(((self.bits >> 28) & 1) != 0)
     }
     #[doc = "Bit 9 - Enable TRANS interrupts"]
     #[inline(always)]
     pub fn interrupt_trans_enable(&self) -> INTERRUPT_TRANS_ENABLE_R {
-        INTERRUPT_TRANS_ENABLE_R::new(((self.bits >> 9) & 0x01) != 0)
+        INTERRUPT_TRANS_ENABLE_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 8 - Enable status write interrupts"]
     #[inline(always)]
     pub fn interrupt_ws_enable(&self) -> INTERRUPT_WS_ENABLE_R {
-        INTERRUPT_WS_ENABLE_R::new(((self.bits >> 8) & 0x01) != 0)
+        INTERRUPT_WS_ENABLE_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 7 - Enable status read interrupts"]
     #[inline(always)]
     pub fn interrupt_rs_enable(&self) -> INTERRUPT_RS_ENABLE_R {
-        INTERRUPT_RS_ENABLE_R::new(((self.bits >> 7) & 0x01) != 0)
+        INTERRUPT_RS_ENABLE_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 6 - Enable buffer write interrupts"]
     #[inline(always)]
     pub fn interrupt_wb_enable(&self) -> INTERRUPT_WB_ENABLE_R {
-        INTERRUPT_WB_ENABLE_R::new(((self.bits >> 6) & 0x01) != 0)
+        INTERRUPT_WB_ENABLE_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 5 - Enable buffer read interrupts"]
     #[inline(always)]
     pub fn interrupt_rb_enable(&self) -> INTERRUPT_RB_ENABLE_R {
-        INTERRUPT_RB_ENABLE_R::new(((self.bits >> 5) & 0x01) != 0)
+        INTERRUPT_RB_ENABLE_R::new(((self.bits >> 5) & 1) != 0)
     }
 }
 impl W {
@@ -806,16 +806,25 @@ impl W {
         self
     }
 }
-#[doc = "It is the synchronous reset signal of the module. This bit is self-cleared by hardware.\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_slave](index.html) module"]
+#[doc = "It is the synchronous reset signal of the module. This bit is self-cleared by hardware.\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_slave]
+(index.html) module"]
 pub struct SPI_SLAVE_SPEC;
 impl crate::RegisterSpec for SPI_SLAVE_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [spi_slave::R](R) reader structure"]
+#[doc = "`read()` method returns [spi_slave::R]
+(R) reader structure"]
 impl crate::Readable for SPI_SLAVE_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [spi_slave::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [spi_slave::W]
+(W) writer structure"]
 impl crate::Writable for SPI_SLAVE_SPEC {
     type Writer = W;
 }
