@@ -175,7 +175,7 @@ impl<'a> SLV_WRSTA_DUMMY_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
@@ -212,7 +212,7 @@ impl<'a> SLV_RDSTA_DUMMY_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
@@ -249,7 +249,7 @@ impl<'a> SLV_WRBUF_DUMMY_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
@@ -286,7 +286,7 @@ impl<'a> SLV_RDBUF_DUMMY_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
@@ -323,7 +323,7 @@ impl<'a> SPI_STATUS_FAST_ENABLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 26)) | ((value as u32 & 0x01) << 26);
+        self.w.bits = (self.w.bits & !(1 << 26)) | ((value as u32 & 1) << 26);
         self.w
     }
 }
@@ -360,7 +360,7 @@ impl<'a> SPI_STATUS_READ_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
+        self.w.bits = (self.w.bits & !(1 << 25)) | ((value as u32 & 1) << 25);
         self.w
     }
 }
@@ -388,32 +388,32 @@ impl R {
     #[doc = "Bit 3 - In the slave mode, it is the enable bit of \"dummy\" phase for \"write-status\" operations."]
     #[inline(always)]
     pub fn slv_wrsta_dummy_en(&self) -> SLV_WRSTA_DUMMY_EN_R {
-        SLV_WRSTA_DUMMY_EN_R::new(((self.bits >> 3) & 0x01) != 0)
+        SLV_WRSTA_DUMMY_EN_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 2 - In the slave mode, it is the enable bit of \"dummy\" phase for \"read-status\" operations."]
     #[inline(always)]
     pub fn slv_rdsta_dummy_en(&self) -> SLV_RDSTA_DUMMY_EN_R {
-        SLV_RDSTA_DUMMY_EN_R::new(((self.bits >> 2) & 0x01) != 0)
+        SLV_RDSTA_DUMMY_EN_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 1 - In the slave mode, it is the enable bit of \"dummy\" phase for \"write-buffer\" operations."]
     #[inline(always)]
     pub fn slv_wrbuf_dummy_en(&self) -> SLV_WRBUF_DUMMY_EN_R {
-        SLV_WRBUF_DUMMY_EN_R::new(((self.bits >> 1) & 0x01) != 0)
+        SLV_WRBUF_DUMMY_EN_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 0 - In the slave mode, it is the enable bit of \"dummy\" phase for \"read-buffer\" operations."]
     #[inline(always)]
     pub fn slv_rdbuf_dummy_en(&self) -> SLV_RDBUF_DUMMY_EN_R {
-        SLV_RDBUF_DUMMY_EN_R::new((self.bits & 0x01) != 0)
+        SLV_RDBUF_DUMMY_EN_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 26 - Enable fast spi slave status"]
     #[inline(always)]
     pub fn spi_status_fast_enable(&self) -> SPI_STATUS_FAST_ENABLE_R {
-        SPI_STATUS_FAST_ENABLE_R::new(((self.bits >> 26) & 0x01) != 0)
+        SPI_STATUS_FAST_ENABLE_R::new(((self.bits >> 26) & 1) != 0)
     }
     #[doc = "Bit 25 - Enable spi slave status"]
     #[inline(always)]
     pub fn spi_status_read(&self) -> SPI_STATUS_READ_R {
-        SPI_STATUS_READ_R::new(((self.bits >> 25) & 0x01) != 0)
+        SPI_STATUS_READ_R::new(((self.bits >> 25) & 1) != 0)
     }
 }
 impl W {
