@@ -67,7 +67,7 @@ impl<'a> SPI_USR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(1 << 18)) | ((value as u32 & 1) << 18);
         self.w
     }
 }
@@ -104,7 +104,7 @@ impl<'a> SPI_READ_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
         self.w
     }
 }
@@ -141,7 +141,7 @@ impl<'a> SPI_WRITE_ENABLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
+        self.w.bits = (self.w.bits & !(1 << 30)) | ((value as u32 & 1) << 30);
         self.w
     }
 }
@@ -178,7 +178,7 @@ impl<'a> SPI_WRITE_DISABLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
+        self.w.bits = (self.w.bits & !(1 << 29)) | ((value as u32 & 1) << 29);
         self.w
     }
 }
@@ -215,7 +215,7 @@ impl<'a> SPI_READ_ID_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 28)) | ((value as u32 & 0x01) << 28);
+        self.w.bits = (self.w.bits & !(1 << 28)) | ((value as u32 & 1) << 28);
         self.w
     }
 }
@@ -252,7 +252,7 @@ impl<'a> SPI_READ_SR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(1 << 27)) | ((value as u32 & 1) << 27);
         self.w
     }
 }
@@ -289,7 +289,7 @@ impl<'a> SPI_WRITE_SR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 26)) | ((value as u32 & 0x01) << 26);
+        self.w.bits = (self.w.bits & !(1 << 26)) | ((value as u32 & 1) << 26);
         self.w
     }
 }
@@ -326,7 +326,7 @@ impl<'a> SPI_PP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
+        self.w.bits = (self.w.bits & !(1 << 25)) | ((value as u32 & 1) << 25);
         self.w
     }
 }
@@ -363,7 +363,7 @@ impl<'a> SPI_SE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(1 << 24)) | ((value as u32 & 1) << 24);
         self.w
     }
 }
@@ -400,7 +400,7 @@ impl<'a> SPI_BE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
+        self.w.bits = (self.w.bits & !(1 << 23)) | ((value as u32 & 1) << 23);
         self.w
     }
 }
@@ -437,7 +437,7 @@ impl<'a> SPI_CE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(1 << 22)) | ((value as u32 & 1) << 22);
         self.w
     }
 }
@@ -474,7 +474,7 @@ impl<'a> SPI_DP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(1 << 21)) | ((value as u32 & 1) << 21);
         self.w
     }
 }
@@ -511,7 +511,7 @@ impl<'a> SPI_RES_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(1 << 20)) | ((value as u32 & 1) << 20);
         self.w
     }
 }
@@ -548,7 +548,7 @@ impl<'a> SPI_HPM_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(1 << 19)) | ((value as u32 & 1) << 19);
         self.w
     }
 }
@@ -556,72 +556,72 @@ impl R {
     #[doc = "Bit 18 - In the master mode, it is the start bit of a single operation. Self-clear by hardware"]
     #[inline(always)]
     pub fn spi_usr(&self) -> SPI_USR_R {
-        SPI_USR_R::new(((self.bits >> 18) & 0x01) != 0)
+        SPI_USR_R::new(((self.bits >> 18) & 1) != 0)
     }
     #[doc = "Bit 31"]
     #[inline(always)]
     pub fn spi_read(&self) -> SPI_READ_R {
-        SPI_READ_R::new(((self.bits >> 31) & 0x01) != 0)
+        SPI_READ_R::new(((self.bits >> 31) & 1) != 0)
     }
     #[doc = "Bit 30"]
     #[inline(always)]
     pub fn spi_write_enable(&self) -> SPI_WRITE_ENABLE_R {
-        SPI_WRITE_ENABLE_R::new(((self.bits >> 30) & 0x01) != 0)
+        SPI_WRITE_ENABLE_R::new(((self.bits >> 30) & 1) != 0)
     }
     #[doc = "Bit 29"]
     #[inline(always)]
     pub fn spi_write_disable(&self) -> SPI_WRITE_DISABLE_R {
-        SPI_WRITE_DISABLE_R::new(((self.bits >> 29) & 0x01) != 0)
+        SPI_WRITE_DISABLE_R::new(((self.bits >> 29) & 1) != 0)
     }
     #[doc = "Bit 28"]
     #[inline(always)]
     pub fn spi_read_id(&self) -> SPI_READ_ID_R {
-        SPI_READ_ID_R::new(((self.bits >> 28) & 0x01) != 0)
+        SPI_READ_ID_R::new(((self.bits >> 28) & 1) != 0)
     }
     #[doc = "Bit 27"]
     #[inline(always)]
     pub fn spi_read_sr(&self) -> SPI_READ_SR_R {
-        SPI_READ_SR_R::new(((self.bits >> 27) & 0x01) != 0)
+        SPI_READ_SR_R::new(((self.bits >> 27) & 1) != 0)
     }
     #[doc = "Bit 26"]
     #[inline(always)]
     pub fn spi_write_sr(&self) -> SPI_WRITE_SR_R {
-        SPI_WRITE_SR_R::new(((self.bits >> 26) & 0x01) != 0)
+        SPI_WRITE_SR_R::new(((self.bits >> 26) & 1) != 0)
     }
     #[doc = "Bit 25"]
     #[inline(always)]
     pub fn spi_pp(&self) -> SPI_PP_R {
-        SPI_PP_R::new(((self.bits >> 25) & 0x01) != 0)
+        SPI_PP_R::new(((self.bits >> 25) & 1) != 0)
     }
     #[doc = "Bit 24"]
     #[inline(always)]
     pub fn spi_se(&self) -> SPI_SE_R {
-        SPI_SE_R::new(((self.bits >> 24) & 0x01) != 0)
+        SPI_SE_R::new(((self.bits >> 24) & 1) != 0)
     }
     #[doc = "Bit 23"]
     #[inline(always)]
     pub fn spi_be(&self) -> SPI_BE_R {
-        SPI_BE_R::new(((self.bits >> 23) & 0x01) != 0)
+        SPI_BE_R::new(((self.bits >> 23) & 1) != 0)
     }
     #[doc = "Bit 22"]
     #[inline(always)]
     pub fn spi_ce(&self) -> SPI_CE_R {
-        SPI_CE_R::new(((self.bits >> 22) & 0x01) != 0)
+        SPI_CE_R::new(((self.bits >> 22) & 1) != 0)
     }
     #[doc = "Bit 21"]
     #[inline(always)]
     pub fn spi_dp(&self) -> SPI_DP_R {
-        SPI_DP_R::new(((self.bits >> 21) & 0x01) != 0)
+        SPI_DP_R::new(((self.bits >> 21) & 1) != 0)
     }
     #[doc = "Bit 20"]
     #[inline(always)]
     pub fn spi_res(&self) -> SPI_RES_R {
-        SPI_RES_R::new(((self.bits >> 20) & 0x01) != 0)
+        SPI_RES_R::new(((self.bits >> 20) & 1) != 0)
     }
     #[doc = "Bit 19"]
     #[inline(always)]
     pub fn spi_hpm(&self) -> SPI_HPM_R {
-        SPI_HPM_R::new(((self.bits >> 19) & 0x01) != 0)
+        SPI_HPM_R::new(((self.bits >> 19) & 1) != 0)
     }
 }
 impl W {
