@@ -67,7 +67,7 @@ impl<'a> SPI_USR_COMMAND_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
         self.w
     }
 }
@@ -104,7 +104,7 @@ impl<'a> SPI_USR_ADDR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
+        self.w.bits = (self.w.bits & !(1 << 30)) | ((value as u32 & 1) << 30);
         self.w
     }
 }
@@ -141,7 +141,7 @@ impl<'a> SPI_USR_DUMMY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
+        self.w.bits = (self.w.bits & !(1 << 29)) | ((value as u32 & 1) << 29);
         self.w
     }
 }
@@ -178,7 +178,7 @@ impl<'a> SPI_USR_MISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 28)) | ((value as u32 & 0x01) << 28);
+        self.w.bits = (self.w.bits & !(1 << 28)) | ((value as u32 & 1) << 28);
         self.w
     }
 }
@@ -215,7 +215,7 @@ impl<'a> SPI_USR_MOSI_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(1 << 27)) | ((value as u32 & 1) << 27);
         self.w
     }
 }
@@ -252,7 +252,7 @@ impl<'a> REG_USR_MOSI_HIGHPART_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
+        self.w.bits = (self.w.bits & !(1 << 25)) | ((value as u32 & 1) << 25);
         self.w
     }
 }
@@ -289,7 +289,7 @@ impl<'a> REG_USR_MISO_HIGHPART_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(1 << 24)) | ((value as u32 & 1) << 24);
         self.w
     }
 }
@@ -326,7 +326,7 @@ impl<'a> SPI_SIO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(1 << 16)) | ((value as u32 & 1) << 16);
         self.w
     }
 }
@@ -363,7 +363,7 @@ impl<'a> SPI_FWRITE_QIO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
@@ -400,7 +400,7 @@ impl<'a> SPI_FWRITE_DIO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
@@ -437,7 +437,7 @@ impl<'a> SPI_FWRITE_QUAD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
@@ -474,7 +474,7 @@ impl<'a> SPI_FWRITE_DUAL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
@@ -511,7 +511,7 @@ impl<'a> SPI_WR_BYTE_ORDER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
@@ -548,7 +548,7 @@ impl<'a> SPI_RD_BYTE_ORDER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
@@ -585,7 +585,7 @@ impl<'a> SPI_CK_I_EDGE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
@@ -622,7 +622,7 @@ impl<'a> SPI_CK_O_EDGE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
@@ -659,7 +659,7 @@ impl<'a> SPI_CS_SETUP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
@@ -696,7 +696,7 @@ impl<'a> SPI_CS_HOLD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
@@ -733,7 +733,7 @@ impl<'a> SPI_AHB_USER_COMMAND_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
@@ -770,7 +770,7 @@ impl<'a> SPI_FLASH_MODE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
@@ -807,7 +807,7 @@ impl<'a> SPI_AHB_USER_COMMAND_4BYTE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
@@ -844,7 +844,7 @@ impl<'a> SPI_DUPLEX_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
@@ -852,112 +852,112 @@ impl R {
     #[doc = "Bit 31 - This bit enable the \"command\" phase of an operation."]
     #[inline(always)]
     pub fn spi_usr_command(&self) -> SPI_USR_COMMAND_R {
-        SPI_USR_COMMAND_R::new(((self.bits >> 31) & 0x01) != 0)
+        SPI_USR_COMMAND_R::new(((self.bits >> 31) & 1) != 0)
     }
     #[doc = "Bit 30 - This bit enable the \"address\" phase of an operation."]
     #[inline(always)]
     pub fn spi_usr_addr(&self) -> SPI_USR_ADDR_R {
-        SPI_USR_ADDR_R::new(((self.bits >> 30) & 0x01) != 0)
+        SPI_USR_ADDR_R::new(((self.bits >> 30) & 1) != 0)
     }
     #[doc = "Bit 29 - This bit enable the \"dummy\" phase of an operation."]
     #[inline(always)]
     pub fn spi_usr_dummy(&self) -> SPI_USR_DUMMY_R {
-        SPI_USR_DUMMY_R::new(((self.bits >> 29) & 0x01) != 0)
+        SPI_USR_DUMMY_R::new(((self.bits >> 29) & 1) != 0)
     }
     #[doc = "Bit 28 - This bit enable the \"read-data\" phase of an operation."]
     #[inline(always)]
     pub fn spi_usr_miso(&self) -> SPI_USR_MISO_R {
-        SPI_USR_MISO_R::new(((self.bits >> 28) & 0x01) != 0)
+        SPI_USR_MISO_R::new(((self.bits >> 28) & 1) != 0)
     }
     #[doc = "Bit 27 - This bit enable the \"write-data\" phase of an operation."]
     #[inline(always)]
     pub fn spi_usr_mosi(&self) -> SPI_USR_MOSI_R {
-        SPI_USR_MOSI_R::new(((self.bits >> 27) & 0x01) != 0)
+        SPI_USR_MOSI_R::new(((self.bits >> 27) & 1) != 0)
     }
     #[doc = "Bit 25 - 1: \"write-data\" phase only access to high-part of the buffer spi_w8~spi_w15"]
     #[inline(always)]
     pub fn reg_usr_mosi_highpart(&self) -> REG_USR_MOSI_HIGHPART_R {
-        REG_USR_MOSI_HIGHPART_R::new(((self.bits >> 25) & 0x01) != 0)
+        REG_USR_MOSI_HIGHPART_R::new(((self.bits >> 25) & 1) != 0)
     }
     #[doc = "Bit 24 - 1: \"read-data\" phase only access to high-part of the buffer spi_w8~spi_w15"]
     #[inline(always)]
     pub fn reg_usr_miso_highpart(&self) -> REG_USR_MISO_HIGHPART_R {
-        REG_USR_MISO_HIGHPART_R::new(((self.bits >> 24) & 0x01) != 0)
+        REG_USR_MISO_HIGHPART_R::new(((self.bits >> 24) & 1) != 0)
     }
     #[doc = "Bit 16 - 1: mosi and miso signals share the same pin"]
     #[inline(always)]
     pub fn spi_sio(&self) -> SPI_SIO_R {
-        SPI_SIO_R::new(((self.bits >> 16) & 0x01) != 0)
+        SPI_SIO_R::new(((self.bits >> 16) & 1) != 0)
     }
     #[doc = "Bit 15 - In the write operations, \"address\" phase and \"read-data\" phase apply 4 signals"]
     #[inline(always)]
     pub fn spi_fwrite_qio(&self) -> SPI_FWRITE_QIO_R {
-        SPI_FWRITE_QIO_R::new(((self.bits >> 15) & 0x01) != 0)
+        SPI_FWRITE_QIO_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bit 14 - In the write operations, \"address\" phase and \"read-data\" phase apply 2 signals"]
     #[inline(always)]
     pub fn spi_fwrite_dio(&self) -> SPI_FWRITE_DIO_R {
-        SPI_FWRITE_DIO_R::new(((self.bits >> 14) & 0x01) != 0)
+        SPI_FWRITE_DIO_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 13 - In the write operations, \"read-data\" phase apply 4 signals"]
     #[inline(always)]
     pub fn spi_fwrite_quad(&self) -> SPI_FWRITE_QUAD_R {
-        SPI_FWRITE_QUAD_R::new(((self.bits >> 13) & 0x01) != 0)
+        SPI_FWRITE_QUAD_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 12 - In the write operations, \"read-data\" phase apply 2 signals"]
     #[inline(always)]
     pub fn spi_fwrite_dual(&self) -> SPI_FWRITE_DUAL_R {
-        SPI_FWRITE_DUAL_R::new(((self.bits >> 12) & 0x01) != 0)
+        SPI_FWRITE_DUAL_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 11 - In \"command\", \"address\", \"write-data\" (MOSI) phases, 1: little-endian; 0: big_endian"]
     #[inline(always)]
     pub fn spi_wr_byte_order(&self) -> SPI_WR_BYTE_ORDER_R {
-        SPI_WR_BYTE_ORDER_R::new(((self.bits >> 11) & 0x01) != 0)
+        SPI_WR_BYTE_ORDER_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 10 - In \"read-data\" (MISO) phase, 1: little-endian; 0: big_endian"]
     #[inline(always)]
     pub fn spi_rd_byte_order(&self) -> SPI_RD_BYTE_ORDER_R {
-        SPI_RD_BYTE_ORDER_R::new(((self.bits >> 10) & 0x01) != 0)
+        SPI_RD_BYTE_ORDER_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 6 - In the slave mode, 1: rising-edge; 0: falling-edge"]
     #[inline(always)]
     pub fn spi_ck_i_edge(&self) -> SPI_CK_I_EDGE_R {
-        SPI_CK_I_EDGE_R::new(((self.bits >> 6) & 0x01) != 0)
+        SPI_CK_I_EDGE_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - In the master mode, 1: rising-edge; 0: falling-edge"]
     #[inline(always)]
     pub fn spi_ck_o_edge(&self) -> SPI_CK_O_EDGE_R {
-        SPI_CK_O_EDGE_R::new(((self.bits >> 7) & 0x01) != 0)
+        SPI_CK_O_EDGE_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 5 - spi cs is enable when spi is in prepare phase. 1: enable 0: disable."]
     #[inline(always)]
     pub fn spi_cs_setup(&self) -> SPI_CS_SETUP_R {
-        SPI_CS_SETUP_R::new(((self.bits >> 5) & 0x01) != 0)
+        SPI_CS_SETUP_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 4 - spi cs keep low when spi is in done phase. 1: enable 0: disable."]
     #[inline(always)]
     pub fn spi_cs_hold(&self) -> SPI_CS_HOLD_R {
-        SPI_CS_HOLD_R::new(((self.bits >> 4) & 0x01) != 0)
+        SPI_CS_HOLD_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 3 - reserved"]
     #[inline(always)]
     pub fn spi_ahb_user_command(&self) -> SPI_AHB_USER_COMMAND_R {
-        SPI_AHB_USER_COMMAND_R::new(((self.bits >> 3) & 0x01) != 0)
+        SPI_AHB_USER_COMMAND_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 2"]
     #[inline(always)]
     pub fn spi_flash_mode(&self) -> SPI_FLASH_MODE_R {
-        SPI_FLASH_MODE_R::new(((self.bits >> 2) & 0x01) != 0)
+        SPI_FLASH_MODE_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 1 - reserved"]
     #[inline(always)]
     pub fn spi_ahb_user_command_4byte(&self) -> SPI_AHB_USER_COMMAND_4BYTE_R {
-        SPI_AHB_USER_COMMAND_4BYTE_R::new(((self.bits >> 1) & 0x01) != 0)
+        SPI_AHB_USER_COMMAND_4BYTE_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 0 - set spi in full duplex mode"]
     #[inline(always)]
     pub fn spi_duplex(&self) -> SPI_DUPLEX_R {
-        SPI_DUPLEX_R::new((self.bits & 0x01) != 0)
+        SPI_DUPLEX_R::new((self.bits & 1) != 0)
     }
 }
 impl W {
