@@ -35,12 +35,16 @@ impl R {
         FRC1_COUNT_R::new((self.bits & 0x007f_ffff) as u32)
     }
 }
-#[doc = "the current value of the counter. It is a decreasingcounter.\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [frc1_count](index.html) module"]
+#[doc = "the current value of the counter. It is a decreasingcounter.\n\nThis register you can [`read`]
+(crate::generic::Reg::read). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [frc1_count]
+(index.html) module"]
 pub struct FRC1_COUNT_SPEC;
 impl crate::RegisterSpec for FRC1_COUNT_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [frc1_count::R](R) reader structure"]
+#[doc = "`read()` method returns [frc1_count::R]
+(R) reader structure"]
 impl crate::Readable for FRC1_COUNT_SPEC {
     type Reader = R;
 }
