@@ -57,7 +57,7 @@ impl<'a> FRC2_ALARM_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u32) -> &'a mut W {
-        self.w.bits = value as u32;
+        self.w.bits = value;
         self.w
     }
 }
@@ -65,7 +65,7 @@ impl R {
     #[doc = "Bits 0:31 - the alarm value for the counter"]
     #[inline(always)]
     pub fn frc2_alarm(&self) -> FRC2_ALARM_R {
-        FRC2_ALARM_R::new(self.bits as u32)
+        FRC2_ALARM_R::new(self.bits)
     }
 }
 impl W {
@@ -81,16 +81,25 @@ impl W {
         self
     }
 }
-#[doc = "the alarm value for the counter\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [frc2_alarm](index.html) module"]
+#[doc = "the alarm value for the counter\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [frc2_alarm]
+(index.html) module"]
 pub struct FRC2_ALARM_SPEC;
 impl crate::RegisterSpec for FRC2_ALARM_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [frc2_alarm::R](R) reader structure"]
+#[doc = "`read()` method returns [frc2_alarm::R]
+(R) reader structure"]
 impl crate::Readable for FRC2_ALARM_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [frc2_alarm::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [frc2_alarm::W]
+(W) writer structure"]
 impl crate::Writable for FRC2_ALARM_SPEC {
     type Writer = W;
 }
