@@ -32,15 +32,19 @@ impl R {
     #[doc = "Bits 0:31 - the current value of the counter. It is a increasingcounter."]
     #[inline(always)]
     pub fn frc2_count(&self) -> FRC2_COUNT_R {
-        FRC2_COUNT_R::new(self.bits as u32)
+        FRC2_COUNT_R::new(self.bits)
     }
 }
-#[doc = "the current value of the counter. It is a increasingcounter.\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [frc2_count](index.html) module"]
+#[doc = "the current value of the counter. It is a increasingcounter.\n\nThis register you can [`read`]
+(crate::generic::Reg::read). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [frc2_count]
+(index.html) module"]
 pub struct FRC2_COUNT_SPEC;
 impl crate::RegisterSpec for FRC2_COUNT_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [frc2_count::R](R) reader structure"]
+#[doc = "`read()` method returns [frc2_count::R]
+(R) reader structure"]
 impl crate::Readable for FRC2_COUNT_SPEC {
     type Reader = R;
 }
