@@ -57,7 +57,7 @@ impl<'a> UART_ID_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u32) -> &'a mut W {
-        self.w.bits = value as u32;
+        self.w.bits = value;
         self.w
     }
 }
@@ -65,7 +65,7 @@ impl R {
     #[doc = "Bits 0:31"]
     #[inline(always)]
     pub fn uart_id(&self) -> UART_ID_R {
-        UART_ID_R::new(self.bits as u32)
+        UART_ID_R::new(self.bits)
     }
 }
 impl W {
@@ -81,16 +81,25 @@ impl W {
         self
     }
 }
-#[doc = "UART_ID\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [uart_id](index.html) module"]
+#[doc = "UART_ID\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [uart_id]
+(index.html) module"]
 pub struct UART_ID_SPEC;
 impl crate::RegisterSpec for UART_ID_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [uart_id::R](R) reader structure"]
+#[doc = "`read()` method returns [uart_id::R]
+(R) reader structure"]
 impl crate::Readable for UART_ID_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [uart_id::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [uart_id::W]
+(W) writer structure"]
 impl crate::Writable for UART_ID_SPEC {
     type Writer = W;
 }
