@@ -67,7 +67,7 @@ impl<'a> UART_DTR_INV_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(1 << 24)) | ((value as u32 & 1) << 24);
         self.w
     }
 }
@@ -104,7 +104,7 @@ impl<'a> UART_RTS_INV_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
+        self.w.bits = (self.w.bits & !(1 << 23)) | ((value as u32 & 1) << 23);
         self.w
     }
 }
@@ -141,7 +141,7 @@ impl<'a> UART_TXD_INV_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(1 << 22)) | ((value as u32 & 1) << 22);
         self.w
     }
 }
@@ -178,7 +178,7 @@ impl<'a> UART_DSR_INV_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(1 << 21)) | ((value as u32 & 1) << 21);
         self.w
     }
 }
@@ -215,7 +215,7 @@ impl<'a> UART_CTS_INV_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(1 << 20)) | ((value as u32 & 1) << 20);
         self.w
     }
 }
@@ -252,7 +252,7 @@ impl<'a> UART_RXD_INV_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(1 << 19)) | ((value as u32 & 1) << 19);
         self.w
     }
 }
@@ -289,7 +289,7 @@ impl<'a> TXFIFO_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(1 << 18)) | ((value as u32 & 1) << 18);
         self.w
     }
 }
@@ -326,7 +326,7 @@ impl<'a> RXFIFO_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(1 << 17)) | ((value as u32 & 1) << 17);
         self.w
     }
 }
@@ -363,7 +363,7 @@ impl<'a> TX_FLOW_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
@@ -400,7 +400,7 @@ impl<'a> UART_LOOPBACK_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
@@ -437,7 +437,7 @@ impl<'a> TXD_BRK_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
@@ -474,7 +474,7 @@ impl<'a> SW_DTR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
@@ -511,7 +511,7 @@ impl<'a> SW_RTS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
@@ -538,7 +538,7 @@ impl<'a> STOP_BIT_NUM_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 4)) | ((value as u32 & 0x03) << 4);
+        self.w.bits = (self.w.bits & !(3 << 4)) | ((value as u32 & 3) << 4);
         self.w
     }
 }
@@ -565,7 +565,7 @@ impl<'a> BIT_NUM_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 2)) | ((value as u32 & 0x03) << 2);
+        self.w.bits = (self.w.bits & !(3 << 2)) | ((value as u32 & 3) << 2);
         self.w
     }
 }
@@ -602,7 +602,7 @@ impl<'a> PARITY_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
@@ -639,7 +639,7 @@ impl<'a> PARITY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
@@ -647,87 +647,87 @@ impl R {
     #[doc = "Bit 24 - Set this bit to inverse uart dtr level"]
     #[inline(always)]
     pub fn uart_dtr_inv(&self) -> UART_DTR_INV_R {
-        UART_DTR_INV_R::new(((self.bits >> 24) & 0x01) != 0)
+        UART_DTR_INV_R::new(((self.bits >> 24) & 1) != 0)
     }
     #[doc = "Bit 23 - Set this bit to inverse uart rts level"]
     #[inline(always)]
     pub fn uart_rts_inv(&self) -> UART_RTS_INV_R {
-        UART_RTS_INV_R::new(((self.bits >> 23) & 0x01) != 0)
+        UART_RTS_INV_R::new(((self.bits >> 23) & 1) != 0)
     }
     #[doc = "Bit 22 - Set this bit to inverse uart txd level"]
     #[inline(always)]
     pub fn uart_txd_inv(&self) -> UART_TXD_INV_R {
-        UART_TXD_INV_R::new(((self.bits >> 22) & 0x01) != 0)
+        UART_TXD_INV_R::new(((self.bits >> 22) & 1) != 0)
     }
     #[doc = "Bit 21 - Set this bit to inverse uart dsr level"]
     #[inline(always)]
     pub fn uart_dsr_inv(&self) -> UART_DSR_INV_R {
-        UART_DSR_INV_R::new(((self.bits >> 21) & 0x01) != 0)
+        UART_DSR_INV_R::new(((self.bits >> 21) & 1) != 0)
     }
     #[doc = "Bit 20 - Set this bit to inverse uart cts level"]
     #[inline(always)]
     pub fn uart_cts_inv(&self) -> UART_CTS_INV_R {
-        UART_CTS_INV_R::new(((self.bits >> 20) & 0x01) != 0)
+        UART_CTS_INV_R::new(((self.bits >> 20) & 1) != 0)
     }
     #[doc = "Bit 19 - Set this bit to inverse uart rxd level"]
     #[inline(always)]
     pub fn uart_rxd_inv(&self) -> UART_RXD_INV_R {
-        UART_RXD_INV_R::new(((self.bits >> 19) & 0x01) != 0)
+        UART_RXD_INV_R::new(((self.bits >> 19) & 1) != 0)
     }
     #[doc = "Bit 18 - Set this bit to reset uart tx fifo"]
     #[inline(always)]
     pub fn txfifo_rst(&self) -> TXFIFO_RST_R {
-        TXFIFO_RST_R::new(((self.bits >> 18) & 0x01) != 0)
+        TXFIFO_RST_R::new(((self.bits >> 18) & 1) != 0)
     }
     #[doc = "Bit 17 - Set this bit to reset uart rx fifo"]
     #[inline(always)]
     pub fn rxfifo_rst(&self) -> RXFIFO_RST_R {
-        RXFIFO_RST_R::new(((self.bits >> 17) & 0x01) != 0)
+        RXFIFO_RST_R::new(((self.bits >> 17) & 1) != 0)
     }
     #[doc = "Bit 15 - Set this bit to enable uart tx hardware flow control"]
     #[inline(always)]
     pub fn tx_flow_en(&self) -> TX_FLOW_EN_R {
-        TX_FLOW_EN_R::new(((self.bits >> 15) & 0x01) != 0)
+        TX_FLOW_EN_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bit 14 - Set this bit to enable uart loopback test mode"]
     #[inline(always)]
     pub fn uart_loopback(&self) -> UART_LOOPBACK_R {
-        UART_LOOPBACK_R::new(((self.bits >> 14) & 0x01) != 0)
+        UART_LOOPBACK_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 8 - RESERVED, DO NOT CHANGE THIS BIT"]
     #[inline(always)]
     pub fn txd_brk(&self) -> TXD_BRK_R {
-        TXD_BRK_R::new(((self.bits >> 8) & 0x01) != 0)
+        TXD_BRK_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 7 - sw dtr"]
     #[inline(always)]
     pub fn sw_dtr(&self) -> SW_DTR_R {
-        SW_DTR_R::new(((self.bits >> 7) & 0x01) != 0)
+        SW_DTR_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 6 - sw rts"]
     #[inline(always)]
     pub fn sw_rts(&self) -> SW_RTS_R {
-        SW_RTS_R::new(((self.bits >> 6) & 0x01) != 0)
+        SW_RTS_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bits 4:5 - Set stop bit: 1:1bit 2:1.5bits 3:2bits"]
     #[inline(always)]
     pub fn stop_bit_num(&self) -> STOP_BIT_NUM_R {
-        STOP_BIT_NUM_R::new(((self.bits >> 4) & 0x03) as u8)
+        STOP_BIT_NUM_R::new(((self.bits >> 4) & 3) as u8)
     }
     #[doc = "Bits 2:3 - Set bit num: 0:5bits 1:6bits 2:7bits 3:8bits"]
     #[inline(always)]
     pub fn bit_num(&self) -> BIT_NUM_R {
-        BIT_NUM_R::new(((self.bits >> 2) & 0x03) as u8)
+        BIT_NUM_R::new(((self.bits >> 2) & 3) as u8)
     }
     #[doc = "Bit 1 - Set this bit to enable uart parity check"]
     #[inline(always)]
     pub fn parity_en(&self) -> PARITY_EN_R {
-        PARITY_EN_R::new(((self.bits >> 1) & 0x01) != 0)
+        PARITY_EN_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 0 - Set parity check: 0:even 1:odd, UART CONFIG1"]
     #[inline(always)]
     pub fn parity(&self) -> PARITY_R {
-        PARITY_R::new((self.bits & 0x01) != 0)
+        PARITY_R::new((self.bits & 1) != 0)
     }
 }
 impl W {
@@ -823,16 +823,25 @@ impl W {
         self
     }
 }
-#[doc = "UART CONFIG0(UART0 and UART1)\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [uart_conf0](index.html) module"]
+#[doc = "UART CONFIG0(UART0 and UART1)\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [uart_conf0]
+(index.html) module"]
 pub struct UART_CONF0_SPEC;
 impl crate::RegisterSpec for UART_CONF0_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [uart_conf0::R](R) reader structure"]
+#[doc = "`read()` method returns [uart_conf0::R]
+(R) reader structure"]
 impl crate::Readable for UART_CONF0_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [uart_conf0::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [uart_conf0::W]
+(W) writer structure"]
 impl crate::Writable for UART_CONF0_SPEC {
     type Writer = W;
 }
