@@ -42,16 +42,25 @@ impl W {
         self
     }
 }
-#[doc = "The current watchdog stage\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [stage](index.html) module"]
+#[doc = "The current watchdog stage\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [stage]
+(index.html) module"]
 pub struct STAGE_SPEC;
 impl crate::RegisterSpec for STAGE_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [stage::R](R) reader structure"]
+#[doc = "`read()` method returns [stage::R]
+(R) reader structure"]
 impl crate::Readable for STAGE_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [stage::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [stage::W]
+(W) writer structure"]
 impl crate::Writable for STAGE_SPEC {
     type Writer = W;
 }
